@@ -392,7 +392,7 @@ class BaseStudentDetailPDFView(BaseStudentPDFView):
         for day in data:
             for period in data[day]:
                 periods[period] = 0
-        periods = list(periods.keys())
+        periods = sorted(periods.keys())
 
         widths = '4cm'
         for period in periods:
@@ -645,7 +645,7 @@ class AbsencesByDayPDFView(BasePDFView):
         for student in data:
             for period in data[student]:
                 periods[period] = 0
-        return list(periods.keys())
+        return sorted(periods.keys())
 
     def date_heading(self):
         day = self.getDay()
