@@ -193,7 +193,7 @@ class HideUnhideReportSheetsLink(flourish.page.LinkViewlet,
 class FlourishReportSheetsBase(FlourishSchooYearMixin):
 
     def sheets(self):
-        return [sheet for sheet in self.all_sheets() if not sheet['checked']]
+        return [sheet for sheet in self.all_sheets() if sheet['checked']]
 
     def all_sheets(self):
         if self.has_schoolyear:
@@ -207,7 +207,7 @@ class FlourishReportSheetsBase(FlourishSchooYearMixin):
                 deployment = deployments.setdefault(index, {
                     'obj': sheet,
                     'index': str(index),
-                    'checked': sheet.hidden,
+                    'checked': not sheet.hidden,
                     'terms': [False] * len(schoolyear),
                     })
                 for index, term in enumerate(schoolyear.values()):
@@ -215,12 +215,25 @@ class FlourishReportSheetsBase(FlourishSchooYearMixin):
                     if sheet.__name__.startswith(deployedKey):
                         deployment['terms'][index] = True
             sheets = [v for k, v in sorted(deployments.items())]
-            return ([sheet for sheet in sheets if not sheet['checked']] +
-                    [sheet for sheet in sheets if sheet['checked']])
+            return ([sheet for sheet in sheets if sheet['checked']] +
+                    [sheet for sheet in sheets if not sheet['checked']])
         else:
             return []
 
 
+class FlourishManageReportSheetTemplatesOverview(FlourishReportSheetsBase,
+                                                 flourish.page.Content):
+    """A flourish viewlet for showing report sheet templates in school view"""
+
+    body_template = ViewPageTemplateFile(
+        'templates/f_manage_report_sheet_templates_overview.pt')
+
+    @property
+    def templates(self):
+        root = IGradebookRoot(ISchoolToolApplication(None))
+        return list(root.templates.values())
+
+
 class FlourishManageReportSheetsOverview(FlourishReportSheetsBase,
                                          flourish.page.Content):
     """A flourish viewlet for showing deployed report sheets in school view"""
@@ -391,20 +404,20 @@ class FlourishHideUnhideReportSheetsView(FlourishReportSheetsBase,
         if 'CANCEL' in self.request:
             self.request.response.redirect(self.nextURL())
         elif 'SUBMIT' in self.request:
-            hidden = self.request.get('hidden', [])
+            visible = self.request.get('visible', [])
             root = IGradebookRoot(ISchoolToolApplication(None))
             schoolyear = self.schoolyear
             for sheet in root.deployed.values():
                 if not sheet.__name__.startswith(schoolyear.__name__):
                     continue
                 index = sheet.__name__[sheet.__name__.rfind('_') + 1:]
-                self.handleSheet(sheet, index, hidden)
+                self.handleSheet(sheet, index, visible)
             self.request.response.redirect(self.nextURL())
 
-    def handleSheet(self, sheet, index, hidden):
-        if index in hidden and not sheet.hidden:
+    def handleSheet(self, sheet, index, visible):
+        if index not in visible and not sheet.hidden:
             sheet.hidden = True
-        elif index not in hidden and sheet.hidden:
+        elif index in visible and sheet.hidden:
             sheet.hidden = False
         else:
             return
@@ -500,6 +513,12 @@ class FlourishReportSheetEditView(flourish.form.Form, form.EditForm):
     def title(self):
         return self.context.title
 
+    def display_scoresystem(self, activity):
+        ss = activity.scoresystem
+        if IRangedValuesScoreSystem.providedBy(ss):
+            return '%s - %s' % (ss.min, ss.max)
+        return ss.title
+
     def update(self):
         if 'form-submitted' in self.request:
             for activity in self.context.values():
@@ -551,18 +570,18 @@ class IReportScoreSystem(Interface):
         vocabulary='schooltool.gradebook.reportscoresystems',
         required=True)
 
-    min = Int(
-        title=_("Minimum"),
-        description=_("Lowest integer score value possible"),
-        min=0,
-        required=False)
-
     max = Int(
         title=_("Maximum"),
         description=_("Highest integer score value possible"),
         min=0,
         required=False)
 
+    min = Int(
+        title=_("Minimum"),
+        description=_("Lowest integer score value possible"),
+        min=0,
+        required=False)
+
 
 class ReportScoresSystem(object):
     implements(IReportScoreSystem)
