@@ -52,7 +52,6 @@ from schooltool.requirement.scoresystem import RangedValuesScoreSystem
 GRADEBOOK_SORTING_KEY = 'schooltool.gradebook.sorting'
 CURRENT_SECTION_TAUGHT_KEY = 'schooltool.gradebook.currentsectiontaught'
 CURRENT_SECTION_ATTENDED_KEY = 'schooltool.gradebook.currentsectionattended'
-CURRENT_WORKSHEET_KEY = 'schooltool.gradebook.currentworksheet'
 DUE_DATE_FILTER_KEY = 'schooltool.gradebook.duedatefilter'
 COLUMN_PREFERENCES_KEY = 'schooltool.gradebook.columnpreferences'
 
@@ -179,7 +178,7 @@ def getLinkedActivityScore(evaluatee, activity):
 
 
 @adapter(requirement.interfaces.IHaveEvaluations,
-         interfaces.IWorksheet)
+         interfaces.IActivityWorksheet)
 @implementer(requirement.interfaces.IScore)
 def getWorksheetAverageScore(evaluatee, worksheet):
     gradebook = interfaces.IGradebook(worksheet)
@@ -346,28 +345,16 @@ class GradebookBase(object):
                 return 0, UNSCORED
 
     def getCurrentWorksheet(self, person):
-        person = proxy.removeSecurityProxy(person)
-        ann = annotation.interfaces.IAnnotations(person)
-        if CURRENT_WORKSHEET_KEY not in ann:
-            ann[CURRENT_WORKSHEET_KEY] = PersistentDict()
-        if self.worksheets:
-            default = self.worksheets[0]
-        else:
-            default = None
-        section_id = hash(IKeyReference(self.section))
-        worksheet = ann[CURRENT_WORKSHEET_KEY].get(section_id, default)
-        if worksheet is not None and worksheet.hidden:
-            return default
-        return worksheet
+        section = self.section
+        activities = interfaces.IActivities(section)
+        current = activities.getCurrentWorksheet(person)
+        return current
 
     def setCurrentWorksheet(self, person, worksheet):
-        person = proxy.removeSecurityProxy(person)
+        section = self.section
+        activities = interfaces.IActivities(section)
         worksheet = proxy.removeSecurityProxy(worksheet)
-        ann = annotation.interfaces.IAnnotations(person)
-        if CURRENT_WORKSHEET_KEY not in ann:
-            ann[CURRENT_WORKSHEET_KEY] = PersistentDict()
-        section_id = hash(IKeyReference(self.section))
-        ann[CURRENT_WORKSHEET_KEY][section_id] = worksheet
+        activities.setCurrentWorksheet(person, worksheet)
 
     def getDueDateFilter(self, person):
         person = proxy.removeSecurityProxy(person)
@@ -441,7 +428,7 @@ class GradebookBase(object):
 
 class Gradebook(GradebookBase):
     implements(interfaces.IGradebook)
-    adapts(interfaces.IWorksheet)
+    adapts(interfaces.IActivityWorksheet)
 
     def __init__(self, context):
         super(Gradebook, self).__init__(context)
@@ -451,7 +438,7 @@ class Gradebook(GradebookBase):
 
 class MyGrades(GradebookBase):
     implements(interfaces.IMyGrades)
-    adapts(interfaces.IWorksheet)
+    adapts(interfaces.IActivityWorksheet)
 
     def __init__(self, context):
         super(MyGrades, self).__init__(context)
@@ -505,13 +492,13 @@ class StudentGradebookFormAdapter(object):
             return ''
         elif interfaces.ILinkedColumnActivity.providedBy(activity):
             sourceObj = getSourceObj(activity.source)
-            if interfaces.IWorksheet.providedBy(sourceObj):
+            if interfaces.IActivityWorksheet.providedBy(sourceObj):
                 return '%.1f' % score.value
         return score.value
 
 
 def getWorksheetSection(worksheet):
-    """Adapt IWorksheet to ISection."""
+    """Adapt IActivityWorksheet to ISection."""
     return worksheet.__parent__.__parent__
 
 
